@@ -61,21 +61,6 @@ OC.L10N.register(
     "Add group or team" : "Añadir grupo o equipo",
     "{size} used" : "{size} usados",
     "Other …" : "Otro …",
-    "You can not remove your own read permission." : "No puede quitarse a Ud. mismo el permiso de lectura.",
-    "Group folders" : "Carpetas de grupo",
-    "Admin configured folders shared with everyone in a group" : "Carpetas configuradas por la administración compartidas con todos los miembros de un grupo",
-    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Carpetas compartidas con todos en un grupo configuradas por un administrador.\n\nLas carpetas se pueden configurar desde *Carpetas de grupo* en los ajustes de administración.\n\nDespués de crear una carpeta, el administrador puede dar acceso a ésta a uno o más grupos, controlar sus permisos de escritura/o de compartir y asignar una cuota para la carpeta.",
-    "Group folder" : "Carpeta de grupo",
-    "Open group folder" : "Abrir carpeta de grupo",
-    "List of group folders." : "Lista de carpetas de grupo.",
-    "No group folders yet" : "No existen carpetas de grupo aún",
-    "Group folders will show up here" : "Las carpetas de grupo aparecerán aquí",
-    "Group folder admin delegation" : "Delegación de administración para carpetas de grupo",
-    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud le permite delegar la administración de las carpetas de grupo a usuarios no administradores.",
-    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Especifique a continuación los grupos que tendrán permitido gestionar las carpetas de grupos y utilizar su API/REST.",
-    "They will have access to all group folders." : "Tendrán acceso a todas las carpetas de grupo.",
-    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Especifique a continuación los grupos que tendrán permitido solamente gestionar las carpetas de grupos y utilizar su API/REST.",
-    "They will only have access to group folders for which they have advanced permissions." : "Solo tendrán acceso a las carpetas de grupo para las cuales tienen permisos avanzados.",
     "Admin configured folders shared with everyone in a team" : "Carpetas compartidas con todo un equipo, configuradas por un administrador",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Carpetas compartidas con todo un equipo, configuradas por los administradores.\n\nLas carpetas se pueden configurar desde *Carpetas de equipo* en los ajustes de administración.\n\nDespués de crear una carpeta, el administrador puede dar acceso a ésta a uno o más equipo, controlar sus permisos de escritura/compartir y asignar una cuota para la carpeta.",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Carpetas compartidas con todos en un equipo configuradas por un administrador.\n\nLas carpetas se pueden configurar desde *Carpetas de Equipos* en las configuraciones de administración.\n\nDespués de crear una carpeta, el administrador puede dar acceso a la carpeta a uno o más equipos, controlar sus permisos de escritura/compartir y asignar una cuota para la carpeta.\nA partir de Hub10/Nextcloud 31, el administrador debe ser parte del equipo para tener la posibilidad de asignar una carpeta de equipo al mismo."
