@@ -58,18 +58,6 @@ OC.L10N.register(
     "Add group or team" : "Добавить группу или команду",
     "{size} used" : "использовано {size}",
     "Other …" : "Прочее...",
-    "You can not remove your own read permission." : "Вы не можете удалить свои собственные права на чтение.",
-    "Group folders" : "Папки групп",
-    "Admin configured folders shared with everyone in a group" : "Папки, настроенные администратором, являются общими для всех членов группы",
-    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Папки, настроенные администратором, доступны для общего доступа всем членам группы.\n\nПапки можно настроить в разделе *Групповые папки* в настройках администратора.\n\nПосле создания папки администратор может предоставить к ней доступ одной или нескольким группам, управлять их правами на запись и совместное использование, а также задать квоту для папки.",
-    "Group folder" : "Групповая папка",
-    "Open group folder" : "Открыть Групповую папку",
-    "List of group folders." : "Список Групповых папок.",
-    "No group folders yet" : "Пока нет Групповых папок",
-    "Group folders will show up here" : "Здесь будут отображаться Групповые папки",
-    "Group folder admin delegation" : "Делегирование полномочий администратора Групповой папки",
-    "They will have access to all group folders." : "Они будут иметь доступ ко всем Групповым папкам.",
-    "They will only have access to group folders for which they have advanced permissions." : "Они будут иметь доступ только к тем Групповым папкам, для которых у них есть расширенные права.",
     "Admin configured folders shared with everyone in a team" : "Папки, настроенные администратором, являются общими для всех членов команды",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Папки, настроенные администратором, доступны для общего доступа всем членам команды.\n\nПапки можно настроить в разделе *Командные папки* в настройках администратора.\n\nПосле создания папки администратор может предоставить к ней доступ одной или нескольким командам, управлять их правами на запись и совместное использование, а также задать квоту для папки.",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Папки, настроенные администратором, доступны для общего доступа всем членам команды.\n\nПапки можно настроить в разделе *Командные папки* в настройках администратора.\n\nПосле создания папки администратор может предоставить к ней доступ одной или нескольким командам, управлять их правами на запись и совместное использование, а также задать квоту для папки.\n\nНачиная с Hub 10/Nextcloud 31, администратор должен быть участником команды, чтобы иметь возможность назначить Командную папку."
