@@ -54,18 +54,6 @@ OC.L10N.register(
     "{displayName} (team)" : "{displayName} (tím)",
     "Add group or team" : "Pridať skupinu alebo tím",
     "{size} used" : "{size} použité",
-    "You can not remove your own read permission." : "Nemôžete odobrať vaše vlastné práva na čítanie.",
-    "Group folders" : "Skupinové priečinky",
-    "Admin configured folders shared with everyone in a group" : "Správcom nastavené priečinky, zdieľané s každým v skupine",
-    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Správcom nakonfigurované adresáre zdieľané s každým v skupine.\n\nAdresáre je možné konfigurovať z *Adresáre skupiny* v nastaveniach správcu.\n\nPo vytvorení adresára môže správca poskytnúť prístup k adresáru jednej alebo viacerým skupinám, riadiť ich povolenia na zápis/zdieľanie a prideliť adresáru kvótu.",
-    "Group folder" : "Skupinový priečinok",
-    "Open group folder" : "Otvoriť adresár skupiny",
-    "List of group folders." : "Zoznam skupinových adresárov.",
-    "No group folders yet" : "Žiadne skupinové adresáre",
-    "Group folders will show up here" : "Skupinové adresáre sa zobrazia tu",
-    "Group folder admin delegation" : "Delegácia správcu skupinového adresára",
-    "They will have access to all group folders." : "Budú mať prístup ku všetkým skupinovým adresárom.",
-    "They will only have access to group folders for which they have advanced permissions." : "Budú mať prístup iba k skupinovým adresárom, pre ktoré majú pokročilé oprávnenia.",
     "Admin configured folders shared with everyone in a team" : "Správca nakonfiguroval adresáre zdieľané s každým v tíme",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Správca nakonfiguroval adresáre zdieľané s každým v tíme.\n\nAdresáre je možné konfigurovať z *Tímových adresárov* v nastaveniach správcu.\n\nPo vytvorení adresára môže správca poskytnúť prístup k adresáru jednému alebo viacerým tímom, ovládať ich povolenia na zápis/zdieľanie a prideliť adresáru kvótu.",
     "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Administrátorom nakonfigurované adresáre zdieľané s každým v tíme.\n\nAdresáre je možné konfigurovať z *Tímových adresárov* v nastaveniach administrátora.\n\nPo vytvorení adresára môže administrátor poskytnúť prístup k adresáru jednému alebo viacerým tímom, ovládať ich povolenia na zápis/zdieľanie a prideliť adresáru kvótu.\nOd Hub 10/Nextcloud 31 musí byť administrátor súčasťou tímu, aby mu mohol priradiť adresár Team."
